/* NessusJ 
 * Copyright (C) 1998 Alexis de Bernis <alexisb@mygale.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * This program is a nessusd java client. For any information about
 * the nessus project visit <http://www.nessus.org>
 *
 *      PLEASE READ CAREFULLY NESSUS DOCUMENTATION BEFORE
 *                     USING THIS PROGRAM
 *
 */


import java.lang.*;
import java.awt.*;
import java.io.*;
import java.util.Vector;
import com.sun.java.swing.*;
import java.awt.event.*;


/** This is the main class, it displays the main window and load the prefs.
    From there, you may launch a new attack, open a saved report or edit the
    preferences.

    @author Alexis de Bernis
    @version 980705
    @see Preferences
    @see NessusdConnection
  */
public class NessusJ extends JFrame implements WindowListener,ActionListener
{

/** To instanciate the connection later */
    NessusdConnection connection;

    
    JMenuBar menu;
    JMenu file,edit,help;
    JMenuItem newa,open,quit,about,prefs;
    ImageIcon logo;
    Preferences prefsWindow;


    NessusJ()
    {
        super("NessusJ Alpha 1");             

        addWindowListener(this);

        logo=new ImageIcon("nessusj.gif");
        getContentPane().add(new JLabel(logo));

        menu=new JMenuBar();

        file=new JMenu("File");
        edit=new JMenu("Edit");
        help=new JMenu("?");

        newa=new JMenuItem("New...");
        newa.addActionListener(this);
        open=new JMenuItem("Open...");
        open.addActionListener(this);
        quit=new JMenuItem("Quit");
        quit.addActionListener(this);
        prefs=new JMenuItem("Preferences...");
        prefs.addActionListener(this);
        about=new JMenuItem("About NessusJ...");
        about.addActionListener(this);

        setJMenuBar(menu);

        menu.add(file);
        menu.add(edit);
        menu.add(help);
//        menu.setHelpMenu(help);

        file.add(newa);
        file.add(open);
        file.addSeparator();
        file.add(quit);

        edit.add(prefs);

        help.add(about);

//        setSize(270,170);
        pack();
        setResizable(false);

        prefsWindow=new Preferences(".nessusrc");

        setVisible(true);


    }



/** This method will open a report, parse it and then instanciate a new
    NessusdReport class.
    @see NessusdReport
  */
    private void openReport()
    {
        FileDialog dialog=new FileDialog(this,"Open Report...",FileDialog.LOAD);
        String temp,filename,host,type,description,ports;
        int port;
        DataInputStream fromFile;
        Vector hosts=new Vector();

        dialog.setFile("*.nsr");
        dialog.show();

        if((filename=dialog.getFile())==null)
            return;

        try
        {
            fromFile=new DataInputStream(new FileInputStream(filename));
        }catch(FileNotFoundException e)
        {
            JOptionPane.showMessageDialog(this,"Error: file "+filename+" not found","Error",JOptionPane.ERROR_MESSAGE);
            return;
        }

        try
        {
            while(fromFile.available()!=0)
            {
                temp=fromFile.readLine();

                host=temp.substring(0,temp.indexOf(" "));
                temp=temp.substring(temp.indexOf(" ")+1);

                try
                {
                    ports=temp.substring(0,temp.indexOf(" "));
                    if(ports.equals("General"))
                        port=-1;
                    else
                        port=Integer.parseInt(ports);

                } catch(Exception e)
                {
                    continue;
                }
                
                temp=temp.substring(temp.indexOf(" ")+1);
                type=temp.substring(0,temp.indexOf(" "));
                description=temp.substring(temp.indexOf(" ")+1);
                description=description.replace(';','\n');

                Host cur=getHost(host,hosts);

                if(type.equals("REPORT"))
                {
                    cur.addHole(new Hole(port,description));
                    markAsOpen(new Integer(port),cur);
                }

                if(type.equals("INFO"))
                {
                    cur.addInfo(new Info(port,description));
                    markAsOpen(new Integer(port),cur);
                }
                cur=null;
            }
        }catch(IOException e)
        {
            JOptionPane.showMessageDialog(this,"Error : impossible to read report","Error",JOptionPane.ERROR_MESSAGE);
            return;
        }
        
        new NessusdReport(this, hosts);
    }


/** Parses the command-line args ( as -v) and instanciate NessusJ */

    public static void main(String args[])
    {
        for(int i=0;;i++)
        {
            try
            {
                if(args[i].equalsIgnoreCase("-v"))
                {
                    System.out.println("\nNessusJ (Nessus) 980705 -- (c) Alexis de Bernis <alexisb@mygale.org>\n");
                    System.exit(0);
                }
            }
            catch(IndexOutOfBoundsException e)
            {
                break;
            }
        }
        NessusJ client=new NessusJ();
    }



/** This useful method will try to return the host corresponding
    to the arg "host" given, if this host doesn't exists, it will
    create a new one and return it.
    @see Host
  */

    public Host getHost(String host,Vector hosts)
    {
        for(int i=0;i<hosts.size();i++)
        {
            if(((Host) hosts.elementAt(i)).getName().equals(host))
                return((Host) hosts.elementAt(i));
        }

//*        System.out.println("Unknown machine : "+host+". Creating...");
        Host temp=new Host(host);
        hosts.addElement(temp);
        return(temp);
    }


/** This method mark a port as open on a given host (fixes a bug in report
    display). */

    private void markAsOpen(Integer port,Host host)
    {
        Vector openPorts=host.getOpenPorts();

        for(int i=0;i<openPorts.size();i++)
        {
            if(((Integer) openPorts.elementAt(i)).equals(port))
                return;
        }

        host.addOpenPort(port);
    }

    public void windowClosing(WindowEvent evt)
    {
        prefsWindow.finalize();
        System.exit(0);
    }

    public void actionPerformed(ActionEvent evt)
    {
        String command=evt.getActionCommand();

        if(command.equals("Quit"))
        {
            prefsWindow.finalize();
            System.exit(0);
        }

        if(command.equals("New..."))
            connection=new NessusdConnection(this,prefsWindow);

        if(command.equals("Open..."))
            openReport();

        if(command.equals("Preferences..."))
            prefsWindow.setVisible(true);
            
        if(command.equals("About NessusJ..."))
        {
            new AboutNessusJ(this);
        }

    }






    public void windowClosed(WindowEvent evt ) { }
    public void windowOpened(WindowEvent evt) { }
    public void windowOpening(WindowEvent evt ) { }
    public void windowIconified(WindowEvent evt ) { }
    public void windowActivated(WindowEvent evt ) { }
    public void windowDeiconified(WindowEvent evt ) { }
    public void windowDeactivated(WindowEvent evt ) { }

    


}

